==> ejc-bfyjerp-impl-3.0.0-20241104.063401-15-sources.jar: com/ejianc/business/bid/bean/WinningRegistrationEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标管理-中标登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_winning_registration")
public class WinningRegistrationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pub_unit_id")
    private Long pubUnitId; // 工程类型
    @TableField(value="pub_unit_name")
    private String pubUnitName; // 工程类型名称
    @TableField(value="pub_unit_code")
    private String pubUnitCode; // 工程类型编码
    @TableField(value="contractual_model_id")
    private Long contractualModelId; // 承包方式id
    @TableField(value="contractual_model_name")
    private String contractualModelName; // 承包方式
    @TableField(value="affiliate_member_id")
    private Long affiliateMemberId; // 承包方式id
    @TableField(value="affiliate_member_name")
    private String affiliateMemberName; // 承包方式
    @TableField(value="province_id")
    private Long provinceId; // 项目所属省份id
    @TableField(value="province_code")
    private String provinceCode; // 项目所属省份编码
    @TableField(value="province_name")
    private String provinceName; // 省份名称
    @TableField(value="city_id")
    private Long cityId; // 地级市id
    @TableField(value="city_code")
    private String cityCode; // 地级市编码
    @TableField(value="city_name")
    private String cityName; // 地级市名称
    @TableField(value="bid_winner_id")
    private Long bidWinnerId; // 中标单位id
    @TableField(value="bid_winner_code")
    private String bidWinnerCode; // 中标单位编码
    @TableField(value="bid_winner")
    private String bidWinner; // 中标单位
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 中标价
    @TableField(value="bid_date")
    private Date bidDate; // 中标日期
    @TableField(value="collection_type_name")
    private String collectionTypeName; // 征收方式
    @TableField(value="comprehensive_tax_rate")
    private BigDecimal comprehensiveTaxRate; // 综合税率
    @TableField(value="management_fee")
    private BigDecimal managementFee; // 管理费收取
    @TableField(value="company_part_percent")
    private BigDecimal companyPartPercent; // 公司部分
    @TableField(value="project_manager_part_percent")
    private BigDecimal projectManagerPartPercent; // 业务经理部分+基础提成
    @TableField(value="third_part_percent")
    private BigDecimal thirdPartPercent; // 第三方部分
    @TableField(value="third_part_rec_person_name")
    private String thirdPartRecPersonName; // 第三方收款人信息
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPubUnitId() {
        return pubUnitId;
    }

    public void setPubUnitId(Long pubUnitId) {
        this.pubUnitId = pubUnitId;
    }
    public String getPubUnitName() {
        return pubUnitName;
    }

    public void setPubUnitName(String pubUnitName) {
        this.pubUnitName = pubUnitName;
    }
    public String getPubUnitCode() {
        return pubUnitCode;
    }

    public void setPubUnitCode(String pubUnitCode) {
        this.pubUnitCode = pubUnitCode;
    }
    public Long getContractualModelId() {
        return contractualModelId;
    }

    public void setContractualModelId(Long contractualModelId) {
        this.contractualModelId = contractualModelId;
    }
    public String getContractualModelName() {
        return contractualModelName;
    }

    public void setContractualModelName(String contractualModelName) {
        this.contractualModelName = contractualModelName;
    }
    public Long getAffiliateMemberId() {
        return affiliateMemberId;
    }

    public void setAffiliateMemberId(Long affiliateMemberId) {
        this.affiliateMemberId = affiliateMemberId;
    }
    public String getAffiliateMemberName() {
        return affiliateMemberName;
    }

    public void setAffiliateMemberName(String affiliateMemberName) {
        this.affiliateMemberName = affiliateMemberName;
    }
    public Long getProvinceId() {
        return provinceId;
    }

    public void setProvinceId(Long provinceId) {
        this.provinceId = provinceId;
    }
    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }
    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    public Long getCityId() {
        return cityId;
    }

    public void setCityId(Long cityId) {
        this.cityId = cityId;
    }
    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }
    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    public Long getBidWinnerId() {
        return bidWinnerId;
    }

    public void setBidWinnerId(Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    public String getBidWinnerCode() {
        return bidWinnerCode;
    }

    public void setBidWinnerCode(String bidWinnerCode) {
        this.bidWinnerCode = bidWinnerCode;
    }
    public String getBidWinner() {
        return bidWinner;
    }

    public void setBidWinner(String bidWinner) {
        this.bidWinner = bidWinner;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public String getCollectionTypeName() {
        return collectionTypeName;
    }

    public void setCollectionTypeName(String collectionTypeName) {
        this.collectionTypeName = collectionTypeName;
    }
    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }
    public BigDecimal getManagementFee() {
        return managementFee;
    }

    public void setManagementFee(BigDecimal managementFee) {
        this.managementFee = managementFee;
    }
    public BigDecimal getCompanyPartPercent() {
        return companyPartPercent;
    }

    public void setCompanyPartPercent(BigDecimal companyPartPercent) {
        this.companyPartPercent = companyPartPercent;
    }
    public BigDecimal getProjectManagerPartPercent() {
        return projectManagerPartPercent;
    }

    public void setProjectManagerPartPercent(BigDecimal projectManagerPartPercent) {
        this.projectManagerPartPercent = projectManagerPartPercent;
    }
    public BigDecimal getThirdPartPercent() {
        return thirdPartPercent;
    }

    public void setThirdPartPercent(BigDecimal thirdPartPercent) {
        this.thirdPartPercent = thirdPartPercent;
    }
    public String getThirdPartRecPersonName() {
        return thirdPartRecPersonName;
    }

    public void setThirdPartRecPersonName(String thirdPartRecPersonName) {
        this.thirdPartRecPersonName = thirdPartRecPersonName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20241121.011752-50-sources.jar: com/ejianc/business/bid/bean/WinningRegistrationEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标管理-中标登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_winning_registration")
public class WinningRegistrationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pub_unit_id")
    private Long pubUnitId; // 发包单位
    @TableField(value="pub_unit_name")
    private String pubUnitName; // 发包单位名称
    @TableField(value="pub_unit_code")
    private String pubUnitCode; // 发包单位编码
    @TableField(value="contractual_model_id")
    private Long contractualModelId; // 承包方式id
    @TableField(value="contractual_model_name")
    private String contractualModelName; // 承包方式
    @TableField(value="affiliate_member_id")
    private Long affiliateMemberId; // 所属会员id
    @TableField(value="affiliate_member_name")
    private String affiliateMemberName; // 所属会员
    @TableField(value="province_id")
    private Long provinceId; // 项目所属省份id
    @TableField(value="province_code")
    private String provinceCode; // 项目所属省份编码
    @TableField(value="province_name")
    private String provinceName; // 省份名称
    @TableField(value="city_id")
    private Long cityId; // 地级市id
    @TableField(value="city_code")
    private String cityCode; // 地级市编码
    @TableField(value="city_name")
    private String cityName; // 地级市名称
    @TableField(value="bid_winner_id")
    private Long bidWinnerId; // 中标单位id
    @TableField(value="bid_winner_code")
    private String bidWinnerCode; // 中标单位编码
    @TableField(value="bid_winner")
    private String bidWinner; // 中标单位
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 中标价
    @TableField(value="bid_date")
    private Date bidDate; // 中标日期
    @TableField(value="collection_type_name")
    private String collectionTypeName; // 征收方式
    @TableField(value="comprehensive_tax_rate")
    private BigDecimal comprehensiveTaxRate; // 综合税率
    @TableField(value="management_fee")
    private BigDecimal managementFee; // 管理费收取
    @TableField(value="company_part_percent")
    private BigDecimal companyPartPercent; // 公司部分
    @TableField(value="project_manager_part_percent")
    private BigDecimal projectManagerPartPercent; // 业务经理部分+基础提成
    @TableField(value="third_part_percent")
    private BigDecimal thirdPartPercent; // 第三方部分
    @TableField(value="third_part_rec_person_name")
    private String thirdPartRecPersonName; // 第三方收款人信息
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称

    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPubUnitId() {
        return pubUnitId;
    }

    public void setPubUnitId(Long pubUnitId) {
        this.pubUnitId = pubUnitId;
    }
    public String getPubUnitName() {
        return pubUnitName;
    }

    public void setPubUnitName(String pubUnitName) {
        this.pubUnitName = pubUnitName;
    }
    public String getPubUnitCode() {
        return pubUnitCode;
    }

    public void setPubUnitCode(String pubUnitCode) {
        this.pubUnitCode = pubUnitCode;
    }
    public Long getContractualModelId() {
        return contractualModelId;
    }

    public void setContractualModelId(Long contractualModelId) {
        this.contractualModelId = contractualModelId;
    }
    public String getContractualModelName() {
        return contractualModelName;
    }

    public void setContractualModelName(String contractualModelName) {
        this.contractualModelName = contractualModelName;
    }
    public Long getAffiliateMemberId() {
        return affiliateMemberId;
    }

    public void setAffiliateMemberId(Long affiliateMemberId) {
        this.affiliateMemberId = affiliateMemberId;
    }
    public String getAffiliateMemberName() {
        return affiliateMemberName;
    }

    public void setAffiliateMemberName(String affiliateMemberName) {
        this.affiliateMemberName = affiliateMemberName;
    }
    public Long getProvinceId() {
        return provinceId;
    }

    public void setProvinceId(Long provinceId) {
        this.provinceId = provinceId;
    }
    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }
    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    public Long getCityId() {
        return cityId;
    }

    public void setCityId(Long cityId) {
        this.cityId = cityId;
    }
    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }
    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    public Long getBidWinnerId() {
        return bidWinnerId;
    }

    public void setBidWinnerId(Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    public String getBidWinnerCode() {
        return bidWinnerCode;
    }

    public void setBidWinnerCode(String bidWinnerCode) {
        this.bidWinnerCode = bidWinnerCode;
    }
    public String getBidWinner() {
        return bidWinner;
    }

    public void setBidWinner(String bidWinner) {
        this.bidWinner = bidWinner;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public String getCollectionTypeName() {
        return collectionTypeName;
    }

    public void setCollectionTypeName(String collectionTypeName) {
        this.collectionTypeName = collectionTypeName;
    }
    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }
    public BigDecimal getManagementFee() {
        return managementFee;
    }

    public void setManagementFee(BigDecimal managementFee) {
        this.managementFee = managementFee;
    }
    public BigDecimal getCompanyPartPercent() {
        return companyPartPercent;
    }

    public void setCompanyPartPercent(BigDecimal companyPartPercent) {
        this.companyPartPercent = companyPartPercent;
    }
    public BigDecimal getProjectManagerPartPercent() {
        return projectManagerPartPercent;
    }

    public void setProjectManagerPartPercent(BigDecimal projectManagerPartPercent) {
        this.projectManagerPartPercent = projectManagerPartPercent;
    }
    public BigDecimal getThirdPartPercent() {
        return thirdPartPercent;
    }

    public void setThirdPartPercent(BigDecimal thirdPartPercent) {
        this.thirdPartPercent = thirdPartPercent;
    }
    public String getThirdPartRecPersonName() {
        return thirdPartRecPersonName;
    }

    public void setThirdPartRecPersonName(String thirdPartRecPersonName) {
        this.thirdPartRecPersonName = thirdPartRecPersonName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}
